pub struct ModuleArgs {
pub pkg_prefix: Option<String>,
pub pkg_unit: Option<PkgUnit>,
pub output_dir: Option<PathBuf>,
pub no_cache: bool,
pub cache_dir: Option<PathBuf>,
pub module_name: Option<String>,
pub module_name_regex: Option<String>,
}Fields
pkg_prefix: Option<String>Default value is defined at cdk_ansible::settings::ModuleSettings
pkg_unit: Option<PkgUnit>Specifies the level at which Cargo packages are created:
- ‘namespace’: Creates a package at the namespace level
- ‘collection’: Creates a package at the collection level
- ‘module’: Creates a package at the module level
- ‘None’: Does not create any packages
Package names follow this pattern:
- namespace: ‘cdkam_
’ - collection: ‘cdkam_
_ ’ - module: ‘cdkam_
’
output_dir: Option<PathBuf>Default value is defined at cdk_ansible::settings::ModuleSettings
no_cache: boolDefault value is defined at cdk_ansible::settings::ModuleSettings
cache_dir: Option<PathBuf>Default value is defined at cdk_ansible::settings::ModuleSettings
module_name: Option<String>Specify the ansible module name. (e.g. ‘ansible.builtin.debug’) If not specified, all modules accessible from your ansible environment will be generated.
module_name_regex: Option<String>Specify the ansible module name regex. (e.g. ‘ansible.builtin..*’) If not specified, all modules accessible from your ansible environment will be generated.